using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;


namespace MemDataTable_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private DataTable dt1;

        private void Form1_Load(object sender, System.EventArgs e)
        {
            // Set grid's DataSource
            dt1 = DummyDataCreator.GetData(100);            

            dt1.TableName = "Band 0";           

            dt1.AcceptChanges();

            this.ultraGrid1.SetDataBinding(dt1, null);

            this.ultraGrid1.CreationFilter = new MyCreationFilter();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            UltraGridLayout layout = e.Layout;
            UltraGridBand band = layout.Bands[0];
            UltraGridOverride ov = layout.Override;

            band.Columns["Double 1"].Format = "#,##0.00";
        }
    }

    public class MyCreationFilter : IUIElementCreationFilter, IDisposable
    {
        private Bitmap bmp;

        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            // Is the element a TextUIElement
            var textElement = parent as TextUIElement;
            if (null != textElement)
            {
                // The grid contains lots of TextUIElements - but we only care about the 
                // ones in the cells. We don't want to change headers, or summaries, etc. 
                //
                var cellElement = textElement.GetAncestor(typeof(CellUIElement)) as CellUIElement;
                if (null != cellElement)
                {
                    
                    // If you wanted to limit this to only certain columns, you could
                    // get cellElement.Cell. From the cell, you could get the column
                    // and then examine the column Key or DataType or whatever and
                    // only do this based on any criteria you like. 

                    // IsTextFullyVisible isn't calculated until the element is drawn.
                    // So we need to fake it by telling it to draw into a temporary bitmap
                    // just to it gets calculated. 
                    //
                    EnsureIsTextFullyVisibleHasBeenCalculated(textElement);

                    // Is the text fully visible?
                    if (false == textElement.IsTextFullyVisible)
                    {
                        // If the text is not fully visible, change the display to 
                        // pounds ('#') signs. 
                        textElement.Text = new string('#', textElement.Text.Length);
                    }
                }
            }
        }

        private void EnsureIsTextFullyVisibleHasBeenCalculated(TextUIElement textElement)
        {
            Rectangle rectInsidePadding = textElement.RectInsidePadding;
            if (null == this.bmp ||
                this.bmp.Width < rectInsidePadding.Width ||
                this.bmp.Height < rectInsidePadding.Height)
            {
                if (null != this.bmp)
                    this.bmp.Dispose();

                this.bmp = new Bitmap(rectInsidePadding.Width, rectInsidePadding.Height);
            }

            bool originalTrackCharactersRendered = textElement.TrackCharactersRendered;
            textElement.TrackCharactersRendered = true;

            using (Graphics g = Graphics.FromImage(this.bmp))
            {

                try
                {
                    textElement.Draw(g, rectInsidePadding, false, AlphaBlendMode.Optimized);
                }
                finally
                {
                    textElement.TrackCharactersRendered = originalTrackCharactersRendered;
                }
            }
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            // Do nothing.
            return false;
        }

        void IDisposable.Dispose()
        {
            if (null != this.bmp)
                this.bmp.Dispose();
        }
    }
}